<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: constants.php 3655 2005-09-09 15:52:24Z radek $
*/

/**
 * @package    Max
 * @author     Andrew Hill <andrew@m3.net>
 *
 * A file to set up the environment constants for Max.
 */

/**
 * The environmental constants initialisation function for Max.
 */
function setupConstants()
{
    // Define this version of Max's constants
    define('MAX_VERSION',           '0.3');
    define('MAX_VERSION_READABLE',  'v0.3.11-alpha');
    define('MAX_PRODUCT_NAME',      'Max Media Manager');
    define('MAX_PRODUCT_URL',       'max.awarez.net');
    
    // Old PAN "constants" still required
    define('phpAds_adminDb',  1);
    define('phpAds_rawDb',    2);
    define('phpAds_dbmsname', 'MySQL');
    
    // Database connection constants
    define('MAX_DSN_ARRAY',                 0);
    define('MAX_DSN_STRING',                1);
    $GLOBALS['_MAX']['CONNECTIONS'] =       array();   
    
    // Error codes to use with MAX::raiseError()
    // Start at -100 in order not to conflict with PEAR::DB error codes
    define('MAX_ERROR_INVALIDARGS',         -101);  // Wrong args to function
    define('MAX_ERROR_INVALIDCONFIG',       -102);  // Something wrong with the config
    define('MAX_ERROR_NODATA',              -103);  // No data available
    define('MAX_ERROR_NOCLASS',             -104);  // No class exists
    define('MAX_ERROR_NOMETHOD',            -105);  // No method exists
    define('MAX_ERROR_NOAFFECTEDROWS',      -106);  // No rows where affected by update/insert/delete
    define('MAX_ERROR_NOTSUPPORTED'  ,      -107);  // Limit queries on unsuppored databases
    define('MAX_ERROR_INVALIDCALL',         -108);  // Overload getter/setter failure
    define('MAX_ERROR_INVALIDAUTH',         -109);
    define('MAX_ERROR_EMAILFAILURE',        -110);
    define('MAX_ERROR_DBFAILURE',           -111);
    define('MAX_ERROR_DBTRANSACTIONFAILURE',-112);
    define('MAX_ERROR_BANNEDUSER',          -113);
    define('MAX_ERROR_NOFILE',              -114);
    define('MAX_ERROR_INVALIDFILEPERMS',    -115);
    define('MAX_ERROR_INVALIDSESSION',      -116);
    define('MAX_ERROR_INVALIDPOST',         -117);
    define('MAX_ERROR_INVALIDTRANSLATION',  -118);
    define('MAX_ERROR_FILEUNWRITABLE',      -119);
    define('MAX_ERROR_INVALIDMETHODPERMS',  -120);
    define('MAX_ERROR_INVALIDREQUEST',      -121);
    define('MAX_ERROR_INVALIDTYPE',         -122);
    define('MAX_ERROR_INVALIDOPERATIONINT', -123);
    define('MAX_ERROR_INVALIDBANNERSIZE',   -124);
    define('MAX_ERROR_INVALIDBANNERTYPE',   -125);
    define('MAX_ERROR_ALREADYLINKED',       -126);
    
    // Ad/Zone association link types
    define('MAX_AD_ZONE_LINK_DIRECT',   0);
    define('MAX_AD_ZONE_LINK_NORMAL',   1);
    define('MAX_AD_ZONE_LINK_CATEGORY', 2);
       
    // URL construction constants
    define('MAX_URL_ADMIN',          0);
    define('MAX_URL_IMAGE',          1);
    define('MAX_URL_DEL_SCRIPT',     2);
    define('MAX_URL_DEL_SCRIPT_SSL', 3);
    define('MAX_URL_DEL_IMG',        4);
    define('MAX_URL_DEL_IMG_SSL',    5);
    
    // Connection type constants
    define('MAX_CONNECTION_AD_IMPRESSION',      0);
    define('MAX_CONNECTION_AD_CLICK',           1);
    define('MAX_CONNECTION_MANUAL',             4);
    
    // Campaign deactivation reasons
    // Values must be x^2, as used as binary flags
    define('MAX_PLACEMENT_DISABLED_IMPRESSIONS',  2);
    define('MAX_PLACEMENT_DISABLED_CLICKS',       4);
    define('MAX_PLACEMENT_DISABLED_CONVERSIONS',  8);
    define('MAX_PLACEMENT_DISABLED_DATE',        16);
    
    // Active, inactive agency values
    define('MAX_AGENCY_INACTIVE', 1);
    define('MAX_AGENCY_ACTIVE', 1);
    
    // Time contstants
    define('SECONDS_PER_WEEK', 604800);
    define('MINUTES_PER_WEEK', 10080);
    define('SECONDS_PER_DAY',  86400);
    define('MINUTES_PER_DAY',  1440);
    
    // Connection status types. Only the default conversion
    // status (MAX_CONNECTION_STATUS_APPROVED) is defined (4), which
    // is a conversion type that is approved by default.
    // Note also that only ignore, pending and approved
    // are used as possible starting values (ie. in the
    // campaigns_trackers table.
    define('MAX_CONNECTION_STATUS_IGNORE',      1);
    define('MAX_CONNECTION_STATUS_PENDING',     2);
    define('MAX_CONNECTION_STATUS_ONHOLD',      3);
    define('MAX_CONNECTION_STATUS_APPROVED',    4);
    define('MAX_CONNECTION_STATUS_DISAPPROVED', 5);
    define('MAX_CONNECTION_STATUS_DUPLICATE',   6);
    
    $GLOBALS['_MAX']['STATUSES'] = array(
        MAX_CONNECTION_STATUS_IGNORE      => 'strStatusIgnore',       // start value
        MAX_CONNECTION_STATUS_PENDING     => 'strStatusPending',      // start value
        MAX_CONNECTION_STATUS_ONHOLD      => 'strStatusOnHold',
        MAX_CONNECTION_STATUS_APPROVED    => 'strStatusApproved',     // start value
        MAX_CONNECTION_STATUS_DISAPPROVED => 'strStatusDisapproved',
        MAX_CONNECTION_STATUS_DUPLICATE   => 'strStatusDuplicate',
    );

    // IP Address used to determine which (if any) MaxMind databases are installed
    define('MAX_MIND_TEST_IP', '24.24.24.24');
    
    // Ensure that the initialisation has not been run before
    if (!(isset($GLOBALS['_MAX']['CONF']))) {
        // Define the Max installation base path
        define('MAX_PATH', dirname(__FILE__));
        // Define the PEAR installation path
        ini_set('include_path', MAX_PATH . '/lib/pear');
        // Define the week to start on Sunday (0) so that the PEAR::Date and
        // PEAR::Date_Calc classes agree on what day is the start of the week
        define('DATE_CALC_BEGIN_WEEKDAY', 0);
        // Set the TZ environment variable, so that PEAR::Date class knows
        // which timezone we are in, and doesn't screw up the dates after using
        // the PEAR::compare() method
        if (getenv('TZ') === false) {
            $diff = date('O') / 100;
            putenv('TZ=GMT'.($diff > 0 ? '-' : '+').abs($diff));
        }
        // Parse the Max configuration file
        $GLOBALS['_MAX']['CONF'] = parseIniFile();
        // Define the Max Cache File location path (required trailing slash)
        if (empty($GLOBALS['_MAX']['CONF']['delivery']['cachePath'])) {
            define('MAX_CACHE', MAX_PATH . '/var/cache/');
        } else {
            define('MAX_CACHE', $GLOBALS['_MAX']['CONF']['delivery']['cachePath']);
        }
        // Define the Max Plugins Cache File location path (required trailing slash)
        if (empty($GLOBALS['_MAX']['CONF']['delivery']['pluginsCachePath'])) {
            define('MAX_PLUGINS_CACHE', MAX_PATH . '/var/plugins/');
        } else {
            define('MAX_PLUGINS_CACHE', $GLOBALS['_MAX']['CONF']['delivery']['pluginsCachePath']);
        }
        // Set the URL access mechanism
        if ($GLOBALS['_MAX']['CONF']['max']['requireSSL']) {
            $GLOBALS['_MAX']['HTTP'] = 'https://';
        } else {
            if (isset($_SERVER['SERVER_PORT'])) {
                if ($_SERVER['SERVER_PORT'] == $GLOBALS['_MAX']['CONF']['max']['sslPort']) {
                    $GLOBALS['_MAX']['HTTP'] = 'https://';
                } else {
                    $GLOBALS['_MAX']['HTTP'] = 'http://';
                }
            }
        }
    }
}

// Run the setupConstants() function
setupConstants();

?>
